@@ -1,45 +1,15 @@
 import toml
 from appdirs import *
 import json
+from loguru import logger
 
+logger.remove()
 from name_that_hash import runner as nth
 
 import logging
 import coloredlogs
 
 
-def read_config_file():
-    return read_and_parse_config_file(find_appdirs_location())
-
-
-def find_appdirs_location():
-    # TODO make this OS independent the "/" makes it Windows specific
-    # print(user_config_dir("HashSearch", "Bee-san") + "/config.toml")
-    pass
-    # TODO where does this function exist lol
-    # return user_config_dir("HashSearch", "Bee-san") + "/config.toml"
-
-
-def read_and_parse_config_file(file):
-    config_to_parse = read_file(file)
-
-    if config_to_parse == None:
-        return config_to_parse
-    else:
-        try:
-            return toml.loads(config_to_parse)
-        except:
-            return None
-
-
-def read_file(file):
-    try:
-        with open(file, "r") as out:
-            return out.read()
-    except:
-        return None
-
-
 def cli_config(kwargs):
 
     config = default_config()
@@ -64,7 +34,7 @@ def api_config(hashes: str, sth_api: str = None):
     config = default_config()
     config["hashes"] = create_hash_config(hashes)
     config["api"] = True
-    if not sth_api:
+    if sth_api:
         config["api_keys"]["STH"] = sth_api
     return config
 
